==> discover-5.5.5.tar.xz: discover-5.5.5/libdiscover/backends/ApplicationBackend/libmuonapt/HistoryView/HistoryProxyModel.h <==
/***************************************************************************
 *   Copyright © 2010 Jonathan Thomas <echidnaman@kubuntu.org>             *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or         *
 *   modify it under the terms of the GNU General Public License as        *
 *   published by the Free Software Foundation; either version 2 of        *
 *   the License or (at your option) version 3 or any later version        *
 *   accepted by the membership of KDE e.V. (or its successor approved     *
 *   by the membership of KDE e.V.), which shall act as a proxy            *
 *   defined in Section 14 of version 3 of the license.                    *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>. *
 ***************************************************************************/

#ifndef HISTORYPROXYMODEL_H
#define HISTORYPROXYMODEL_H

#include <QSortFilterProxyModel>

#include <QApt/Package>

class HistoryProxyModel : public QSortFilterProxyModel
{
    Q_OBJECT
public:
    enum {
        HistoryDateRole = Qt::UserRole + 1,
        HistoryActionRole = Qt::UserRole + 2
    };
    HistoryProxyModel(QObject *parent);
    ~HistoryProxyModel();

    void search(const QString &searchText);
    void setStateFilter(QApt::Package::State state);

    bool filterAcceptsRow(int sourceRow, const QModelIndex &sourceParent) const;

protected:
    bool lessThan(const QModelIndex &left, const QModelIndex &right) const;

private:
    QString m_searchText;
    QApt::Package::State m_stateFilter;
};

#endif

==> discover-5.7.3.tar.xz: discover-5.7.3/libdiscover/backends/ApplicationBackend/libmuonapt/HistoryView/HistoryProxyModel.h <==
/***************************************************************************
 *   Copyright © 2010 Jonathan Thomas <echidnaman@kubuntu.org>             *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or         *
 *   modify it under the terms of the GNU General Public License as        *
 *   published by the Free Software Foundation; either version 2 of        *
 *   the License or (at your option) version 3 or any later version        *
 *   accepted by the membership of KDE e.V. (or its successor approved     *
 *   by the membership of KDE e.V.), which shall act as a proxy            *
 *   defined in Section 14 of version 3 of the license.                    *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>. *
 ***************************************************************************/

#ifndef HISTORYPROXYMODEL_H
#define HISTORYPROXYMODEL_H

#include <QSortFilterProxyModel>

#include <QApt/Package>

class HistoryProxyModel : public QSortFilterProxyModel
{
    Q_OBJECT
public:
    enum {
        HistoryDateRole = Qt::UserRole + 1,
        HistoryActionRole = Qt::UserRole + 2
    };
    explicit HistoryProxyModel(QObject *parent);
    ~HistoryProxyModel() override;

    void search(const QString &searchText);
    void setStateFilter(QApt::Package::State state);

    bool filterAcceptsRow(int sourceRow, const QModelIndex &sourceParent) const override;

protected:
    bool lessThan(const QModelIndex &left, const QModelIndex &right) const override;

private:
    QString m_searchText;
    QApt::Package::State m_stateFilter;
};

#endif
